Compare commits

...
Sign in to create a new pull request.

21 commits

Author SHA1 Message Date
Frantisek Sumsal
c9d0190f0e Version 20231130
... (rhbz#2252233)
2023-12-03 20:06:56 +01:00
Zbigniew Jędrzejewski-Szmek
9cac4c4b72 Convert license tag to SPDX 2023-11-21 14:45:56 +01:00
Frantisek Sumsal
948ab3dc5e Version 20231113
... (rhbz#2248590)
2023-11-14 20:12:16 +01:00
Frantisek Sumsal
3325120ae7 Version 20231026
... (rhbz#2246326)
2023-11-03 19:19:19 +01:00
Zbigniew Jędrzejewski-Szmek
bf8e226ec0 Version 20231017
... (rhbz#2243196)

(cherry picked from commit 08ca5376dd)
(cherry picked from commit 2a2d6fa476)
(cherry picked from commit 4c5722ada7)
2023-10-17 20:31:43 +02:00
Zbigniew Jędrzejewski-Szmek
7adbd1113b Version 20230918
... (rhbz#2239389)

(cherry picked from commit 8ecc997ae3)
(cherry picked from commit f174f54bff)
(cherry picked from commit 26b2e08050)
2023-09-18 18:46:29 +02:00
Zbigniew Jędrzejewski-Szmek
5a9880ee4d Use rhbz# in message
This way bodhi should be able to link the update to the bug automatically.

The bug number is moved from the git commit title to the body. We don't really
need this clutter in the git log, it is only useful in the %changelog so that
bodhi can pick it up.

(cherry picked from commit a71f4e415d)
(cherry picked from commit 9d835e0719)
(cherry picked from commit 315aabbfd5)

[skip changelog]
2023-09-18 18:46:24 +02:00
Michel Lind
6f9caaccc2
Revert upstream feature that uses sq >= 0.31.0
Signed-off-by: Michel Lind <salimma@fedoraproject.org>
2023-09-07 14:28:38 -05:00
Frantisek Sumsal
4d99d08fa5 Version 20230821 (#2233045) 2023-08-21 21:05:23 +02:00
Frantisek Sumsal
eb4ccd0db5 Version 20230704 (#2219535) 2023-07-09 23:12:57 +02:00
Frantisek Sumsal
499470c4d9 Version 20230629 (#2218594) 2023-07-01 10:14:11 +02:00
Frantisek Sumsal
c725b11bb6 Version 20230504 (#2193100) 2023-05-08 21:54:52 +02:00
Frantisek Sumsal
539e084481 Version 20230320 (#2180086) 2023-03-24 13:47:48 +01:00
Frantisek Sumsal
91aefec8d5 Version 20230225 (#2172640) 2023-02-28 20:37:00 +01:00
Frantisek Sumsal
6193938a17 Version 20230130 (#2165491) 2023-02-16 13:33:18 +01:00
Frantisek Sumsal
7e05a5449d Version 20221220 (#2154797) 2022-12-27 12:47:51 +01:00
Frantisek Sumsal
0f8ba8076d Version 20221213 (#2153046) 2022-12-15 10:25:44 +01:00
Frantisek Sumsal
2aa9904703 Run integrity & consistency checks 2022-12-15 10:25:44 +01:00
Frantisek Sumsal
cddc357467 Version 20221123 (#2145118) 2022-11-26 21:04:58 +01:00
Frantisek Sumsal
73b0ffe85e Version 20221110 (#2141851) 2022-11-14 20:09:13 +01:00
Frantisek Sumsal
66dc6086f6 Version 20220927 (#2130137) 2022-09-30 12:07:25 +02:00
5 changed files with 122 additions and 6 deletions

17
.gitignore vendored
View file

@ -32,3 +32,20 @@
/archlinux-keyring-20220424.tar.gz
/archlinux-keyring-20220727.tar.gz
/archlinux-keyring-20220831.tar.gz
/archlinux-keyring-20220927.tar.gz
/archlinux-keyring-20221110.tar.gz
/archlinux-keyring-20221123.tar.gz
/archlinux-keyring-20221213.tar.gz
/archlinux-keyring-20221220.tar.gz
/archlinux-keyring-20230130.tar.gz
/archlinux-keyring-20230225.tar.gz
/archlinux-keyring-20230320.tar.gz
/archlinux-keyring-20230504.tar.gz
/archlinux-keyring-20230629.tar.gz
/archlinux-keyring-20230704.tar.gz
/archlinux-keyring-20230821.tar.gz
/archlinux-keyring-20230918.tar.gz
/archlinux-keyring-20231017.tar.gz
/archlinux-keyring-20231026.tar.gz
/archlinux-keyring-20231113.tar.gz
/archlinux-keyring-20231130.tar.gz

View file

@ -0,0 +1,93 @@
From a8e44708937708290e62ad66898119902fd6425f Mon Sep 17 00:00:00 2001
From: Michel Lind <salimma@fedoraproject.org>
Date: Thu, 7 Sep 2023 11:11:00 -0500
Subject: [PATCH] Revert "feat: Replace sq-keyring-linter with sq >= 0.31.0"
For use in distribution packages where sq has not been updated
This reverts commit 3365f8607cadf4c5e87b8e5d582cdbb021c0d267.
---
README.md | 3 ++-
libkeyringctl/ci.py | 2 +-
libkeyringctl/cli.py | 2 +-
libkeyringctl/verify.py | 6 +++---
4 files changed, 7 insertions(+), 6 deletions(-)
diff --git a/README.md b/README.md
index 102e9c3..f409fc5 100644
--- a/README.md
+++ b/README.md
@@ -24,11 +24,12 @@ Build:
Runtime:
* python
-* sequoia-sq >= 0.31.0
+* sequoia-sq
Optional:
* hopenpgp-tools (verify)
+* sq-keyring-linter (verify)
* git (ci)
## Usage
diff --git a/libkeyringctl/ci.py b/libkeyringctl/ci.py
index 7200709..31b0210 100644
--- a/libkeyringctl/ci.py
+++ b/libkeyringctl/ci.py
@@ -10,7 +10,7 @@ from .verify import verify
def ci(working_dir: Path, keyring_root: Path, project_root: Path) -> None:
- """Verify certificates against modern expectations using `sq keyring lint` and hokey
+ """Verify certificates against modern expectations using sq-keyring-linter and hokey
Currently only newly added certificates will be checked against the expectations as existing
keys are not all fully compatible with those assumptions.
diff --git a/libkeyringctl/cli.py b/libkeyringctl/cli.py
index 020f64b..3334c17 100644
--- a/libkeyringctl/cli.py
+++ b/libkeyringctl/cli.py
@@ -118,7 +118,7 @@ verify_parser.add_argument(
)
verify_parser.add_argument("--no-lint-hokey", dest="lint_hokey", action="store_false", help="Do not run hokey lint")
verify_parser.add_argument(
- "--no-lint-sq-keyring", dest="lint_sq_keyring", action="store_false", help="Do not run sq keyring lint"
+ "--no-lint-sq-keyring", dest="lint_sq_keyring", action="store_false", help="Do not run sq-keyring-linter"
)
verify_parser.set_defaults(lint_hokey=True, lint_sq_keyring=True)
diff --git a/libkeyringctl/verify.py b/libkeyringctl/verify.py
index a0c582b..5b7fc7d 100644
--- a/libkeyringctl/verify.py
+++ b/libkeyringctl/verify.py
@@ -29,7 +29,7 @@ def verify( # noqa: ignore=C901
lint_hokey: bool = True,
lint_sq_keyring: bool = True,
) -> None:
"""Verify certificates against modern expectations using `sq keyring lint` and hokey
Parameters
----------
@@ -38,7 +38,7 @@ def verify( # noqa: ignore=C901
sources: A list of username, fingerprint or directories from which to read PGP packet information
(defaults to `keyring_root`)
lint_hokey: Whether to run hokey lint
lint_sq_keyring: Whether to run sq keyring lint
"""
if not sources:
@@ -71,7 +71,7 @@ def verify( # noqa: ignore=C901
keyring_fd = Popen(("sq", "dearmor", f"{str(keyring_path)}"), stdout=PIPE)
print(system(["hokey", "lint"], _stdin=keyring_fd.stdout), end="")
if lint_sq_keyring:
- print(system(["sq", "keyring", "lint", f"{str(keyring_path)}"]), end="")
+ print(system(["sq-keyring-linter", f"{str(keyring_path)}"]), end="")
def verify_integrity(certificate: Path, all_fingerprints: Set[Fingerprint]) -> None: # noqa: ignore=C901
@@ -29,7 +29,7 @@ def verify( # noqa: ignore=C901
lint_sq_keyring: bool = True,
) -> None:
- """Verify certificates against modern expectations using `sq keyring lint` and hokey
+ """Verify certificates against modern expectations using sq-keyring-linter and hokey
Parameters
@@ -38,7 +38,7 @@ def verify( # noqa: ignore=C901
(defaults to `keyring_root`)
lint_hokey: Whether to run hokey lint
- lint_sq_keyring: Whether to run sq keyring lint
+ lint_sq_keyring: Whether to run sq-keyring-linter
"""
if not sources:
--
2.41.0

View file

@ -1,11 +1,12 @@
Name: archlinux-keyring
Version: 20220831
Version: 20231130
Release: %autorelease
Url: https://archlinux.org/packages/core/any/archlinux-keyring/
Source0: https://gitlab.archlinux.org/archlinux/archlinux-keyring/-/archive/%{version}/archlinux-keyring-%{version}.tar.gz
Patch: archlinux-keyring-revert_to_sq-keyring-linter.diff
# see https://wiki.archlinux.org/index.php/Pacman-key for introduction
License: Public Domain
Summary: GPG keys used by Arch distribution to sign packages
License: LicenseRef-Fedora-Public-Domain
Summary: GPG keys used by Arch Linux distribution to sign packages
BuildArch: noarch
BuildRequires: keyrings-filesystem
@ -28,10 +29,13 @@ developers into an RPM package to allow for safe and convenient
installation on Fedora systems.
%prep
%setup -q
%autosetup -p1
%build
%check
make check
%install
%make_install PREFIX=%{_prefix}
mkdir -p %{buildroot}%{_keyringsdir}/

View file

@ -1 +1 @@
SHA512 (archlinux-keyring-20220831.tar.gz) = e753914d0202ec96fc1c6978e8413f93999ca31e70594c42e1dd4c40c1e635208e61b5f32840bd5f1265503213784cb8eb3668464efe1fb477ed080be533b19e
SHA512 (archlinux-keyring-20231130.tar.gz) = 76c495b73b5e3aa8a6bb4c934c75b99ee875a80cecc14426d3351a2bd6f47475ddcdbdb730a67adb00a859eddcc32b570e4335d6fa8717d2a90ba4f090782dbb

View file

@ -32,7 +32,9 @@ if [ "$sum1" != "$sum2" ]; then
fi
git add *.spec
git commit -a -m "Version $version (#$bug)"
git commit -a -m "Version $version
... (rhbz#$bug)"
if [ "$args" = "-u" ]; then
git push